package com.aucma.dms.controller;

//import com.hw.common.core.utils.poi.ExcelUtil;
//import com.hw.common.core.web.controller.BaseController;
//import com.hw.common.core.web.domain.AjaxResult;
//import com.hw.common.core.web.page.TableDataInfo;
//import com.hw.common.log.annotation.Log;
//import com.hw.common.log.enums.BusinessType;
//import com.hw.common.security.annotation.RequiresPermissions;
//import com.aucma.dms.domain.DmsBaseDeviceDebugging;
//import com.aucma.dms.service.IDmsBaseDeviceDebuggingService;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseDeviceDebugging;
import com.aucma.dms.service.IDmsBaseDeviceDebuggingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 设备调试信息Controller
 * 
 * @author xins
 * @date 2024-01-02
 */
@RestController
@RequestMapping("/dms/debugging")
public class DmsBaseDeviceDebuggingController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceDebuggingService dmsBaseDeviceDebuggingService;

    /**
     * 查询设备调试信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        startPage();
        List<DmsBaseDeviceDebugging> list = dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingList(dmsBaseDeviceDebugging);
        return getDataTable(list);
    }

    /**
     * 导出设备调试信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:export')" )
    //@Log(title = "设备调试信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        List<DmsBaseDeviceDebugging> list = dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingList(dmsBaseDeviceDebugging);
        ExcelUtil<DmsBaseDeviceDebugging> util = new ExcelUtil<DmsBaseDeviceDebugging>(DmsBaseDeviceDebugging.class);
        util.exportExcel(response, list, "设备调试信息数据");
    }

    /**
     * 获取设备调试信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:query')" )
    @GetMapping(value = "/{deviceDebuggingId}")
    public AjaxResult getInfo(@PathVariable("deviceDebuggingId") Long deviceDebuggingId)
    {
        return success(dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingByDeviceDebuggingId(deviceDebuggingId));
    }

    /**
     * 新增设备调试信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:add')" )
    //@Log(title = "设备调试信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        return toAjax(dmsBaseDeviceDebuggingService.insertDmsBaseDeviceDebugging(dmsBaseDeviceDebugging));
    }

    /**
     * 修改设备调试信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:edit')" )
    //@Log(title = "设备调试信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        return toAjax(dmsBaseDeviceDebuggingService.updateDmsBaseDeviceDebugging(dmsBaseDeviceDebugging));
    }

    /**
     * 删除设备调试信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:debugging:remove')" )
    //@Log(title = "设备调试信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceDebuggingIds}")
    public AjaxResult remove(@PathVariable Long[] deviceDebuggingIds)
    {
        return toAjax(dmsBaseDeviceDebuggingService.deleteDmsBaseDeviceDebuggingByDeviceDebuggingIds(deviceDebuggingIds));
    }
}
